<?php

namespace Drupal\iubenda\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * The Iubenda settings form.
 */
class IubendaSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'iubenda.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'iubenda.settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('iubenda.settings');

    $form['prefix'] = [
      '#type' => 'markup',
      '#markup' => '<p>' . $this->t('In order to use this module, you need an account set up on <a href="@iubenda_url">Iubenda</a>, and the appropriate cookie policies set up.', ['@iubenda_url' => 'https://www.iubenda.com/']) . '</p>',
    ];

    $form['iubenda'] = [
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-iubenda-cookies',
    ];

    $form['iubenda_cookies'] = [
      '#type' => 'details',
      '#title' => $this->t('Cookie solution'),
      '#group' => 'iubenda',
      '#tree' => TRUE,
    ];

    $form['iubenda_cookies']['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable cookie solution'),
      '#default_value' => $config->get('iubenda_cookies.enabled') ?: FALSE,
      '#group' => 'iubenda',
    ];

    $form['iubenda_cookies']['settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Settings'),
      '#group' => 'iubenda',
      '#states' => [
        'visible' => [
          ':input[name="iubenda_cookies[enabled]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['iubenda_cookies']['settings']['site_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Site ID'),
      '#description' => $this->t('The site ID from Iubenda. This ID is the same across all languages.'),
      '#default_value' => $config->get('iubenda_cookies.settings.site_id') ?: '',
      '#states' => [
        'required' => [
          ':input[name="iubenda_cookies[enabled]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['iubenda_cookies']['settings']['policy_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Policy ID'),
      '#description' => $this->t('The cookie policy ID from Iubenda. This should be language-specific.'),
      '#default_value' => $config->get('iubenda_cookies.settings.policy_id') ?: '',
      '#states' => [
        'required' => [
          ':input[name="iubenda_cookies[enabled]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['iubenda_cookies']['settings']['show_gdpr'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show GDPR'),
      '#default_value' => $config->get('iubenda_cookies.settings.show_gdpr') ?: FALSE,
    ];

    $form['iubenda_cookies']['settings']['show_ccpa'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show CCPA'),
      '#default_value' => $config->get('iubenda_cookies.settings.show_ccpa') ?: FALSE,
    ];

    $form['iubenda_cookies']['settings']['country_detection'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable country detection'),
      '#default_value' => $config->get('iubenda_cookies.settings.country_detection') ?: FALSE,
    ];

    $form['iubenda_cookies']['settings']['position'] = [
      '#type' => 'select',
      '#title' => $this->t('Banner position'),
      '#description' => $this->t('Note that the position chosen may interfere with other UI elements on the web page.'),
      '#options' => [
        'top' => $this->t('Top'),
        'bottom' => $this->t('Bottom'),
        'float-top-left' => $this->t('Float top left'),
        'float-top-right' => $this->t('Float top right'),
        'float-bottom-left' => $this->t('Float bottom left'),
        'float-bottom-right' => $this->t('Float bottom right'),
        'float-top-center' => $this->t('Float top center'),
        'float-bottom-center' => $this->t('Float bottom center'),
        'float-center' => $this->t('Float center'),
      ],
      '#default_value' => $config->get('iubenda_cookies.settings.position') ?: 'float-top-center',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $this->config('iubenda.settings')
      ->set('iubenda_cookies.enabled', $values['iubenda_cookies']['enabled'])
      ->set('iubenda_cookies.settings', $values['iubenda_cookies']['settings'])
      ->save();

    return parent::submitForm($form, $form_state);
  }

}
